```
Usage: vcd gateway services ipsec-vpn enable-logging [OPTIONS] <gateway name>

Options:
  --enable / --disable  enable/disable global logging of IPsec VPN
  -h, --help            Show this message and exit.

```
